==> mythdvd_0.16.orig.tar.gz: mythdvd-0.16/i18n/mythdvd_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythdvd_0.17.orig.tar.gz: mythdvd-0.17/i18n/mythdvd_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
